Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.Gruppe Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.Gruppe einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.Gruppe) | Gemeinde_Modelle.Gruppe |
__str__(self) (Definiert in Gemeinde_Modelle.Gruppe) | Gemeinde_Modelle.Gruppe |
keyFeldNavi (Definiert in Gemeinde_Modelle.Gruppe) | Gemeinde_Modelle.Gruppe | static
R_farbe (Definiert in Gemeinde_Modelle.Gruppe) | Gemeinde_Modelle.Gruppe | static